trident.misc package
====================

Submodules
----------

trident.misc.ipython\_utils module
----------------------------------

.. automodule:: trident.misc.ipython_utils
   :members:
   :undoc-members:
   :show-inheritance:

trident.misc.visualization\_utils module
----------------------------------------

.. automodule:: trident.misc.visualization_utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.misc
   :members:
   :undoc-members:
   :show-inheritance:
